# cronjobfilter
To filter list of cronjobs which are coming under from date and to date.

## Test PyPi: 
pip install -i https://test.pypi.org/simple/ cronjobfilter
<br>
* cronjobfilter==0.0.3

## Example:
Python 3.8.3 (tags/v3.8.3:6f8c832, May 13 2020, 22:37:02) [MSC v.1924 64 bit (AMD64)] on win32
Type "help", "copyright", "credits" or "license" for more information.
>>> from cronjobfilter.cronjobfilter import greet_user
>>>
>>> greet_user("Sam Peter")
Hello my friend Sam Peter ! How are you ?
>>>

